
#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <limits.h>
#include <fx.h>
#include <stdint.h>
#include <FXPNGIcon.h>

static int app_created;

#include "gui.h"


#include "actions.h"


 

 typedef struct radio_item {
   struct radio_item *next;
   FXRadioButton *button;
   int value;
 } radio_item_t;

 typedef struct {
   int *target;
   radio_item_t *head;
 } FYRadioGroup;




static void set_value
  (FYRadioGroup *G, int V)
{
  radio_item_t *T;
  for(T=G->head;T;T=T->next)
    if (T->value==V) 
     T->button->setCheck(TRUE);
    else T->button->setCheck(FALSE);
  G->target[0]= V;
}

static void get_value
  (FYRadioGroup *G,int *R)
{
  *R= G->target[0];
}

static void append(FYRadioGroup *G, FXRadioButton *B, int V)
{
  radio_item_t *T= (radio_item_t*) malloc(sizeof(*T));
  T->button= B;
  T->value= V;
  T->next= G->head;
  G->head= T;
}


static void radio_group_set_value
  (gui_radio_group_t *G, int V)
{
  set_value( (FYRadioGroup*) (G->widget), V);
}

static void radio_group_get_value
  (gui_radio_group_t *G,int *R)
{
  get_value( (FYRadioGroup*) (G->widget), R);
}

static gui_radio_group_class_t
gui_radio_group_class = {
  radio_group_set_value,
  radio_group_get_value,
};



static void button_set_text(gui_button_t *B,const char *text)
{
  FXButton *W= (FXButton*) B->widget;
  W->setText(text);
}

static gui_button_class_t
 gui_button_class= {
  button_set_text,
};


  static FXFont *YQRZ_11;
      static FXFont *YQRZ_16;
   




static void label_set_text(gui_label_t *B, char *text)
{
  FXLabel *W= (FXLabel*) B->widget;
  W->setText(text);
}

static gui_label_class_t
 gui_label_class= {
  label_set_text,
};




static void text_entry_set_text(gui_text_entry_t *B, char *text)
{
  FXTextField *W= (FXTextField*) B->widget;
  W->setText(text);
}

static char* text_entry_get_text(gui_text_entry_t *B)
{
  FXTextField *W= (FXTextField*) B->widget;
  FXString S= W->getText();
  return strdup(S.text());
}

static 
 gui_text_entry_class_t gui_text_entry_class= {
   text_entry_set_text,
   text_entry_get_text
};



static void spinner_set_value(gui_spinner_t *B, int value)
{
  FXSpinner *W= (FXSpinner*) B->widget;
  W->setValue(value);
}

static void spinner_get_value(gui_spinner_t *B, int *ret)
{
  FXSpinner *W= (FXSpinner*) B->widget;
  *ret= W->getValue();
}

static gui_spinner_class_t
 gui_spinner_class= {
  spinner_set_value,
  spinner_get_value,
};




class FYListItem : public FXListItem 
{
  FXDECLARE(FYListItem)
protected:
  FYListItem() : FXListItem() { }
public:
  FYListItem(const FXString& text,FXIcon* ic, void *pdata)
   : FXListItem(text,ic,NULL)
  { data_p= pdata; }
  FYListItem(const FXString& text,FXIcon* ic, int idata)
   : FXListItem(text,ic,NULL)
  { data_i= idata; }
  FYListItem(const FXString& text,FXIcon* ic, double fdata)
   : FXListItem(text,ic,NULL)
  { data_f= fdata; }
  ~FYListItem() { }
// These could be in a union, but who cares about space
  int data_i;
  double data_f;
  void *data_p;
};


FXIMPLEMENT(FYListItem,FXListItem,NULL,0)




static void clear_selection
  (FXList *L)
{
  int i;
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    L->deselectItem(i);
}

static FYListItem* get_selected(FXList *L)
{
   int i, N= L->getNumItems();
   for(i=0;i<N;i++)
     if (L->isItemSelected(i))
       return (FYListItem*) L->getItem(i);
   return 0;
}




static inline FXList* list(gui_intlist_t *IL)
{
  return (FXList*) (IL->widget);
}

static int intlist_get_selected
   (gui_intlist_t* IL, int *ret)
{
  FYListItem *item= get_selected(list(IL));
  if (item) { *ret= item->data_i; return 1; }
  return 0;
}

static void intlist_clear(gui_intlist_t* IL)
{
  list(IL)->clearItems();
}

static int intlist_find_item(gui_intlist_t *IL, int key)
{
  int i;
  FXList* L= list(IL);
  int N= L->getNumItems();
  for(i=0;i<N;i++)
    {
        FYListItem *it= (FYListItem*) L->getItem(i);
        if (it->data_i==key) return i;
    }
  return -1;
}

static int intlist_select_item
  (gui_intlist_t *IL, int key,int sel)
{
  int i= intlist_find_item(IL, key); 
  if (i==-1) return 0;
  if (sel) list(IL)->selectItem(i);
  else list(IL)->deselectItem(i); 
  return 1;
}


static void intlist_append_item
  (gui_intlist_t *IL, const char *text, int key)
{
  list(IL)->appendItem(new FYListItem(text, NULL,key));
}

static void intlist_prepend_item
  (gui_intlist_t *IL, const char *text, int key)
{
  list(IL)->prependItem(new FYListItem(text, NULL,key));
}

static void intlist_insert_item
  (gui_intlist_t *IL, int poskey, const char *text, int key)
{
  int i= intlist_find_item(IL, poskey);
  if (i!=-1)
    list(IL)->insertItem(i, new FYListItem(text, NULL, key));
  else
    list(IL)->appendItem(new FYListItem(text, NULL, key));
}

static void intlist_clear_selection(gui_intlist_t *IL)
{
  clear_selection(list(IL));
}

static void intlist_remove_item(gui_intlist_t *IL, int key)
{
  int i= intlist_find_item(IL, key);
  if (i==-1) return ;
  list(IL)->removeItem(i);
}

static gui_intlist_class_t gui_intlist_class=
{
   intlist_get_selected,
   intlist_select_item,
   intlist_clear_selection,
   intlist_append_item,
   intlist_prepend_item,
   intlist_insert_item,
   intlist_remove_item,
   intlist_clear,
};



static FXList* list(gui_sslist_t *SL)
{
  return (FXList*) SL->widget;
}

static int sslist_get_selected(gui_sslist_t *SL, char **ret)
{
  FYListItem *item= get_selected(list(SL));
  if (!item) return 0;
  *ret= (char*) item->data_p;
  return 1;
}

static int sslist_find_item(gui_sslist_t *SL,const char *key)
{
  FXList *L= list(SL);
  int i, N= L->getNumItems();
  for(i=0;i<N;i++) {
    FYListItem* item= (FYListItem*) L->getItem(i);
    if (!strcmp((char*) item->data_p, key)) return i;
  }
  return -1;
}

static void sslist_append_item(gui_sslist_t *SL, const char *value)
{
  list(SL)->appendItem(new FYListItem(value, NULL, (void*) value));
}
static void sslist_prepend_item(gui_sslist_t *SL, const char *value)
{
  list(SL)->prependItem(new FYListItem(value, NULL, (void*) value));
}
static void sslist_insert_item
      (gui_sslist_t *SL, const char *poskey, const char *value)
{
  int i= sslist_find_item(SL, poskey);
  if (i==-1) sslist_append_item(SL, value);
  else list(SL)->insertItem(i,new FYListItem(value, NULL, (void*) value));
}

static gui_sslist_class_t gui_sslist_class= {
  sslist_get_selected,
  sslist_append_item,
  sslist_prepend_item,
  sslist_insert_item
};



static FXList* list(gui_slist_t *SL)
{
  return (FXList*) SL->widget;
}

static int slist_get_selected(gui_slist_t *SL, char **ret)
{
  FYListItem *item= get_selected(list(SL));
  if (!item) return 0;
  *ret= (char*) item->data_p;
  return 1;
}

static int slist_find_item(gui_slist_t *SL,const char *key)
{
  FXList *L= list(SL);
  int i, N= L->getNumItems();
  for(i=0;i<N;i++) {
    FYListItem* item= (FYListItem*) L->getItem(i);
    if (!strcmp((char*) item->data_p, key)) return i;
  }
  return -1;
}

static void slist_append_item
    (gui_slist_t *SL, const char *value, const char *data)
{
  list(SL)->appendItem(new FYListItem(value, NULL, (void*) data));
}

static void slist_prepend_item
   (gui_slist_t *SL, const char *value,const char *data)
{
  list(SL)->prependItem(new FYListItem(value, NULL, (void*) data));
}

static void slist_insert_item
      (gui_slist_t *SL, const char *poskey,
       const char *value,const char *data)
{
  int i= slist_find_item(SL, poskey);
  if (i==-1) slist_append_item(SL, value,data);
  else list(SL)->insertItem(i,new FYListItem(value, NULL, (void*) data));
}

static void slist_remove_item
      (gui_slist_t *SL, const char *key)
{
  int i= slist_find_item(SL, key);
  if (i!=-1)
     list(SL)->removeItem(i);
}

static gui_slist_class_t gui_slist_class= {
  slist_get_selected,
  slist_append_item,
  slist_prepend_item,
  slist_insert_item,
  slist_remove_item,
};




static void gui_message_console_print
   (gui_message_console_t *mc, const char * fmt,...)
{
   int size=200; char *message; int len; char *atmp;
   va_list ap;
   message= (char*) malloc(size);
   while(1) {
     va_start(ap,fmt);
     len= vsnprintf(message,size, fmt, ap);
     va_end(ap);
     if (len<0) size*= 2;
     else if (len<size) break;
     else size= len+2;
     message= (char*) realloc(atmp= message, size);
     if (!message) {
        free(atmp);
        message= (char*) fmt;
        break;
     }
  } 
  FXText *W= (FXText*) mc->widget;
  W->appendText(message, strlen(message));
  if (message!=fmt) free(message);
   // argh, AUTOSCROLL doesn`t work yet. see
   // http://ruby.11.n6.nabble.com/TEXT-AUTOSCROLL-in-FXText-with-usage-of-FXDataTarget-td3510118.html
  W->makePositionVisible(W->getLength()-1);
}


static void gui_message_console_append
   (gui_message_console_t *mc, const char * str, size_t len)
{
  FXText *W= (FXText*) mc->widget;
  W->appendText(str, len);
   // argh, AUTOSCROLL doesn`t work yet. see
   // http://ruby.11.n6.nabble.com/TEXT-AUTOSCROLL-in-FXText-with-usage-of-FXDataTarget-td3510118.html
  W->makePositionVisible(W->getLength()-1);
}



static void gui_message_console_clear(gui_message_console_t *mc)
{
  FXText *W= (FXText*) mc->widget;
  W->removeText(0, W->getLength()); 
}

static gui_message_console_class_t 
  gui_message_console_class= 
{
  gui_message_console_print,
  gui_message_console_clear,
  gui_message_console_append,
};



static int item_type(FXDirItem *item)
{
  if (item->isDirectory()) return 'D';
  if (item->isSymlink())   return 'L';
  if (item->isChardev())   return 'C';
  if (item->isBlockdev())  return 'B';
  if (item->isFifo())      return 'P';
  if (item->isSocket())    return 'S';
  return 'F';
}

static int dirlist_get_current
  (gui_dir_list_t* DL, const char **Rname, int *Rtype)
{
  FXDirList *L= (FXDirList*) DL->widget;
  FXDirItem *item= (FXDirItem*) L->getCurrentItem();
  if (!item) return 0;
  if (Rname) *Rname= strdup(L->getItemPathname(item).text());
  if (Rtype) *Rtype= item_type(item);
  return 1;
}

static void dirlist_set_current_file
  (gui_dir_list_t *DL, const char *fn)
{
  FXDirList *L= (FXDirList*) DL->widget;
  L->setCurrentFile(fn);
}

static void dirlist_set_current_directory
  (gui_dir_list_t *DL, const char *fn)
{
  FXDirList *L= (FXDirList*) DL->widget;
  L->setDirectory(fn);
}

static gui_dir_list_class_t gui_dir_list_class= {
   dirlist_get_current,
   dirlist_set_current_file,
   dirlist_set_current_directory 
};



static int item_type(FXFileList *L, int item)
{
  if (L->isItemDirectory(item)) return 'D';
  return 'F';
}

static int filelist_get_current
  (gui_file_list_t* DL, const char **Rname, int *Rtype)
{
  FXFileList *L= (FXFileList*) DL->widget;
  FXString cur;
  int item;

  item= L->getCurrentItem();
  if (item<0) return 0;
  cur= L->getCurrentFile();
  if (Rname) *Rname= strdup(cur.text());
  if (Rtype) *Rtype= item_type(L,item);
  return 1;
}

static void filelist_set_current_file
  (gui_file_list_t *FL, const char *fn)
{
  FXFileList *L= (FXFileList*) FL->widget;
  L->setCurrentFile(fn);
}

static void filelist_set_current_directory
  (gui_file_list_t *DL, const char *fn)
{
  FXFileList *L= (FXFileList*) DL->widget;
  L->setDirectory(fn);
}

static void filelist_get_current_directory
  (gui_file_list_t* DL, const char **Rname)
{
  FXFileList *L= (FXFileList*) DL->widget;
  FXString cur;

  cur= L->getDirectory();
  if (Rname) *Rname= strdup(cur.text());
}

static gui_file_list_class_t gui_file_list_class= {
   filelist_get_current,
   filelist_set_current_file,
   filelist_set_current_directory,
   filelist_get_current_directory,
};


 

 static int YQRZ_1(gui_newbutton_t *object         , char* value)
 {
    
       ((FXButton*) object->widget) -> setText(value); return 0; 
 }
 


 

static gui_newbutton_class_t gui_newbutton_class = {
 
 YQRZ_1,



};



  static FXIcon *VFLL1;
  static unsigned char YQRZ_19 []= {
0x89,0x50,0x4e,0x47,0x0d,0x0a,0x1a,0x0a,0x00,0x00,
0x00,0x0d,0x49,0x48,0x44,0x52,0x00,0x00,0x00,0x10,
0x00,0x00,0x00,0x10,0x08,0x06,0x00,0x00,0x00,0x1f,
0xf3,0xff,0x61,0x00,0x00,0x00,0x09,0x70,0x48,0x59,
0x73,0x00,0x00,0x0b,0x13,0x00,0x00,0x0b,0x13,0x01,
0x00,0x9a,0x9c,0x18,0x00,0x00,0x00,0x20,0x63,0x48,
0x52,0x4d,0x00,0x00,0x7a,0x25,0x00,0x00,0x80,0x83,
0x00,0x00,0xf9,0xff,0x00,0x00,0x80,0xe9,0x00,0x00,
0x75,0x30,0x00,0x00,0xea,0x60,0x00,0x00,0x3a,0x98,
0x00,0x00,0x17,0x6f,0x92,0x5f,0xc5,0x46,0x00,0x00,
0x02,0xc5,0x49,0x44,0x41,0x54,0x78,0xda,0x5c,0x93,
0x3f,0x68,0x9d,0x55,0x14,0xc0,0x7f,0xe7,0xde,0xfb,
0xfd,0x79,0xaf,0x2f,0x24,0x79,0x95,0x97,0xb4,0x83,
0xa0,0x0d,0x04,0x8a,0x58,0x44,0x10,0x11,0x4c,0x41,
0x44,0x70,0xd5,0xa5,0x16,0x4b,0xe6,0xae,0x85,0xb8,
0x28,0x34,0x74,0xec,0xd0,0xdd,0xc1,0x49,0xa8,0x9b,
0x0e,0x2e,0x4e,0x42,0x3b,0x88,0xc9,0x22,0x8a,0x94,
0x56,0x28,0x76,0x4a,0x49,0xa0,0x2f,0x11,0xdf,0xf7,
0xde,0x77,0xff,0x7c,0xf7,0x38,0x7c,0x89,0x82,0x07,
0x2e,0x07,0xee,0x39,0xe7,0x37,0x9c,0x7b,0x7f,0xb2,
0xb7,0xf7,0x33,0xff,0x8b,0xcb,0x65,0x59,0x5e,0xaf,
0xab,0x7a,0xcb,0x3a,0x77,0x11,0x20,0xa5,0x78,0xd0,
0xb6,0xed,0xc3,0x10,0xc2,0x7d,0x55,0x7d,0x24,0x22,
0xa8,0x2a,0x00,0x72,0x06,0x50,0x55,0x5b,0x95,0xd5,
0xee,0xea,0xea,0xea,0xad,0xe1,0xb9,0x73,0x43,0x67,
0x2d,0x88,0x9c,0xd5,0xe8,0x52,0xa2,0x69,0x9a,0xf9,
0xf4,0x78,0x7a,0xcf,0x87,0xb0,0x2b,0xd0,0x01,0x38,
0x80,0x9c,0xb3,0x1b,0x8d,0x46,0x5f,0x4f,0x26,0x93,
0x6b,0x45,0x51,0x22,0x00,0x22,0x7d,0x06,0x54,0x04,
0x29,0x0a,0x96,0x57,0x56,0x86,0x83,0xe1,0xe0,0x8b,
0xc3,0xc3,0xc3,0x8d,0xa6,0x69,0x6e,0x88,0x48,0x32,
0xaa,0xca,0xa0,0x1e,0xdc,0x9e,0x4c,0xd6,0xfa,0x61,
0x11,0x0a,0x67,0x59,0xae,0x1d,0x85,0xb3,0x18,0x6b,
0xb1,0xc6,0x60,0x8d,0x41,0x44,0x28,0xcb,0x8a,0xb5,
0xc9,0xfa,0xb5,0xaa,0xaa,0x6e,0xab,0x2a,0xc6,0x88,
0xd9,0x1c,0x8f,0xc7,0x3b,0x45,0x51,0x20,0x22,0xd4,
0x85,0xe5,0xf1,0x49,0xe2,0xcb,0xdf,0x1b,0xc4,0x5a,
0x96,0x06,0x05,0xce,0xb9,0x1e,0x64,0x0d,0xc6,0x18,
0xaa,0xba,0x64,0x3c,0x3e,0xbf,0x23,0x22,0x9b,0xa6,
0xaa,0xab,0xed,0xe1,0x70,0x58,0x01,0x7d,0xd1,0x1a,
0xfe,0x8a,0x70,0xf3,0xc7,0x63,0xde,0xff,0xee,0x90,
0x1f,0xfe,0x6c,0xa8,0x8c,0xe2,0x34,0xd1,0xb6,0x9e,
0xe0,0x3d,0x29,0x75,0x8c,0x46,0xa3,0xaa,0xae,0xeb,
0x6d,0x37,0xa8,0x07,0x57,0x8d,0xb5,0x18,0x11,0x44,
0x04,0x31,0x86,0xd2,0x18,0x30,0x99,0x9f,0x9e,0xcd,
0xf8,0xf0,0xe9,0x94,0x8f,0x5e,0xad,0xf8,0xec,0xad,
0x31,0xaf,0xbf,0x54,0x70,0xd2,0x78,0x16,0x21,0x60,
0xad,0xa5,0x2c,0xca,0xab,0xc6,0x39,0x77,0xe1,0xec,
0xfd,0xce,0x96,0xd7,0x75,0x1d,0xf8,0x05,0x68,0x00,
0x4d,0x7c,0xfb,0xdb,0x0b,0xb6,0xbe,0x7a,0xcc,0xcd,
0xef,0x9f,0x71,0xec,0x33,0x85,0xb5,0x2c,0xe6,0x0b,
0xbc,0xf7,0x17,0xdc,0xbf,0xab,0x96,0x7e,0x38,0xc5,
0x48,0x8a,0x01,0x82,0xef,0xef,0x73,0x07,0x31,0x82,
0xcd,0xa0,0x0a,0x7a,0xda,0x6e,0x0c,0x00,0x2e,0xa5,
0xf4,0x1c,0x78,0xa5,0xef,0xed,0xf0,0x31,0xa2,0x5d,
0x07,0xde,0x43,0xe8,0xc0,0x28,0x1f,0xbf,0x36,0x66,
0xe7,0xdd,0x75,0xae,0x4c,0x2a,0x4e,0x66,0x2d,0x73,
0x1f,0xd0,0x9c,0x51,0xd5,0xe7,0xae,0x6d,0xdb,0x07,
0x39,0xe7,0x77,0x8c,0x58,0x7c,0xf4,0x14,0x64,0x7c,
0x88,0xf0,0xf7,0x9c,0xb7,0x2f,0x2d,0xf3,0xf9,0x7b,
0x2f,0xf3,0xc1,0xc6,0x32,0x21,0x25,0x8e,0x1b,0x4f,
0x4c,0x1d,0x9a,0x33,0xb9,0x3f,0x0f,0x64,0x7f,0x7f,
0x6f,0x73,0x7d,0xfd,0xc2,0xaf,0x4b,0x4b,0x4b,0xd5,
0x6c,0x36,0xc3,0x09,0xfc,0x31,0x0d,0xfc,0x72,0x30,
0xe7,0xd3,0x37,0xd7,0x18,0x16,0x86,0x99,0x4f,0xa4,
0xd4,0x91,0xba,0x44,0x8a,0x89,0x98,0x22,0x8b,0xf9,
0xc2,0xfb,0xe0,0xaf,0x18,0x55,0x7d,0x72,0x3c,0x7d,
0x71,0x37,0x86,0x40,0x8a,0x91,0xb9,0x0f,0x5c,0x5a,
0x71,0x6c,0xbf,0x71,0x9e,0x18,0x23,0xd3,0x59,0x4b,
0x08,0x91,0x98,0xe2,0x29,0xa4,0x23,0x86,0x48,0x8c,
0xf1,0xae,0xaa,0x3e,0x71,0x22,0x42,0xeb,0xfd,0x9d,
0xa3,0xa3,0xa3,0x0d,0xe7,0xdc,0x27,0x22,0x02,0xaa,
0x84,0xd4,0xf5,0x2a,0x28,0x28,0x4a,0xce,0x4a,0xd7,
0x25,0x62,0x88,0xb4,0xbe,0xfd,0x26,0x6b,0xbe,0x23,
0x22,0xbd,0x0b,0x22,0x92,0xe6,0xf3,0xe6,0x86,0x31,
0xf6,0x69,0x51,0x14,0xb7,0x5c,0xe1,0x86,0xd6,0x5a,
0x7a,0xd8,0xa9,0x4c,0x5d,0x47,0x4a,0x69,0x1e,0x63,
0xb8,0xd7,0xe5,0xbc,0xcb,0xa9,0x4c,0xb2,0xbf,0xbf,
0xf7,0xdf,0x1f,0x38,0xd5,0xd9,0x88,0xb9,0x2e,0xc6,
0x6c,0x19,0x23,0x17,0xb5,0x07,0x1c,0xe4,0xdc,0x3d,
0xcc,0xaa,0xf7,0x81,0x47,0x67,0x2a,0x03,0xfc,0x33,
0x00,0x66,0xd5,0x75,0x1e,0x14,0x77,0xfd,0xd6,0x00,
0x00,0x00,0x00,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
0x82,

  };

 

 class VFLL2: public FXMainWindow
 {
  FXDECLARE(VFLL2)
 public:
  enum { ID_FIRST= FXMainWindow::ID_LAST,
         ID_SELF,
         
 YQRZ_4,


 YQRZ_9,


 YQRZ_14,

  

 


 


 


 

      



 


  YQRZ_61,


  YQRZ_66,


  YQRZ_71,


  YQRZ_76,


 YQRZ_82,


  YQRZ_88,


 YQRZ_95,


  YQRZ_102,


 YQRZ_109,


  


 YQRZ_123,


  


  YQRZ_140,


   YQRZ_152,



   YQRZ_155,


 };
  
  FYRadioGroup *radio1;
  int radio1_store;
 // FIXME: I should find some prefix and not use the suffix _store..




  long YQRZ_7(FXObject *object,FXSelector sel, void *arg);
  FXButton *cool_button;



  long YQRZ_12(FXObject *object,FXSelector sel, void *arg);
  FXButton *foo_button;



  long YQRZ_17(FXObject *object,FXSelector sel, void *arg);
  FXButton *allnew;



  
  



  
  



  
  



  
  



  



FXTextField *source_dir;



  
  



  



  


  long YQRZ_64(FXObject *object,FXSelector sel, void *arg);
 

  long YQRZ_69(FXObject *object,FXSelector sel, void *arg);
 

  long YQRZ_74(FXObject *object,FXSelector sel, void *arg);
 

  long YQRZ_79(FXObject *object,FXSelector sel, void *arg);
 


  long YQRZ_85(FXObject *object,FXSelector sel, void *arg);
  


  

  FXList *numbers;


  long YQRZ_91(FXObject *object,FXSelector sel,void* arg);
  



  long YQRZ_98(FXObject *object,FXSelector sel, void *arg);
  


  FXList *strings;


  
  long YQRZ_106(FXObject *object,FXSelector sel,void* arg);



  long YQRZ_112(FXObject *object,FXSelector sel, void *arg);
  


  FXList *string_keys;


  
  



  long YQRZ_126(FXObject *object,FXSelector sel, void *arg);
  



  FXText *econ;


  

   FXDirList *dirs;
   


   FXFileList *files;
   long YQRZ_143(FXObject *object,FXSelector sel,void *arg);
   



   FXText  *textedit;



long YQRZ_153 (FXObject *object,FXSelector sel, void *arg);



   FXButton  *selfbutton;



long YQRZ_156 (FXObject *object,FXSelector sel, void *arg);


  VFLL2(FXApp* a,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs);
  virtual ~VFLL2();
  VFLL2() : FXMainWindow() { }
  long handle_close(FXObject *object,FXSelector sel, void *arg);
 };

 FXDEFMAP(VFLL2) YQRZ_158 []= {
  FXMAPFUNC(SEL_CLOSE, VFLL2::ID_SELF, VFLL2::handle_close),
  
 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_4, VFLL2::YQRZ_7),


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_9, VFLL2::YQRZ_12),


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_14, VFLL2::YQRZ_17),


 


 


 


 


 


 


  FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_61, VFLL2::YQRZ_64),


  FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_66, VFLL2::YQRZ_69),


  FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_71, VFLL2::YQRZ_74),


  FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_76, VFLL2::YQRZ_79),


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_82, VFLL2::YQRZ_85),


  
     FXMAPFUNC(SEL_CLICKED,VFLL2::YQRZ_88,VFLL2::YQRZ_91),
  


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_95, VFLL2::YQRZ_98),


  
  
     FXMAPFUNC(SEL_DOUBLECLICKED,VFLL2::YQRZ_102,VFLL2::YQRZ_106),


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_109, VFLL2::YQRZ_112),


  
  


 
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_123, VFLL2::YQRZ_126),



  



  
    FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_140, VFLL2::YQRZ_143), 
  


  FXMAPFUNC(SEL_CHANGED, VFLL2::YQRZ_152, VFLL2::YQRZ_153),


  FXMAPFUNC(SEL_COMMAND, VFLL2::YQRZ_155, VFLL2::YQRZ_156),


 }; 

 FXIMPLEMENT(VFLL2, FXMainWindow, YQRZ_158, ARRAYNUMBER(YQRZ_158))

 // FIXME: the argument names must be changed so that
 // we can have widgets called 'y' etc.
 VFLL2::VFLL2(
         FXApp* a,const FXString& name,
         FXIcon *ic,FXIcon *mi,FXuint opts,
         FXint x,FXint y,FXint w,FXint h,
         FXint pl,FXint pr,FXint pt,FXint pb,
         FXint hs,FXint vs) :
               FXMainWindow(a,name, ic,mi,opts,
                            x,y,w,h, pl,pr,pt,pb, hs,vs)

 {
   setTarget(this);
   setSelector(ID_SELF);
   

  FYRadioGroup *YQRZ_2;
  YQRZ_2= radio1 = (FYRadioGroup*) malloc(sizeof(* YQRZ_2));
  YQRZ_2->target= & radio1_store;
  YQRZ_2->head= NULL;


  FXVerticalFrame *YQRZ_157= new
    FXVerticalFrame( this,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


  FXHorizontalFrame *YQRZ_18= new
    FXHorizontalFrame( YQRZ_157,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXButton *YQRZ_3;

  YQRZ_3= cool_button =
    new FXButton(YQRZ_18,
      "hello!",
      NULL,
      this ,
      YQRZ_4 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_VT_APART 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        12,
        12,
        12,
        12);

  

  

  

  


    YQRZ_3->setBackColor(FXRGB(0x00,0x00,0xff)); 

         



  FXButton *YQRZ_8;

  YQRZ_8= foo_button =
    new FXButton(YQRZ_18,
      "bye!",
      NULL,
      this ,
      YQRZ_9 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        LAYOUT_FILL_Y |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_VT_APART 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        12,
        12,
        12,
        12);

  
     FXFontDesc YQRZ_10;
     YQRZ_8->getFont()->getFontDesc(YQRZ_10);
  

  
     YQRZ_10.size= 32 * 10;
  

  
     strcpy(YQRZ_10.face, "Courier New");
  

  
    YQRZ_11= new FXFont(FXApp::instance(), YQRZ_10);
    YQRZ_8->setFont(YQRZ_11);
    
  


   

         



  FXButton *YQRZ_13;

  YQRZ_13= allnew =
    new FXButton(YQRZ_18,
      "new-button",
      NULL,
      this ,
      YQRZ_14 ,

        
        
        
        

        
        
        
        

        
        LAYOUT_FILL_Y|
 
        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    YQRZ_13->setBackColor(FXRGB(0xff,0x00,0xff)); 

   
      FXFontDesc YQRZ_15;
      YQRZ_13->getFont()->getFontDesc(YQRZ_15);
      
      
       YQRZ_15.slant= FXFont::Italic;
      
      

      YQRZ_16= new FXFont(FXApp::instance(), YQRZ_15);
      YQRZ_13->setFont(YQRZ_16);
      
  FXHorizontalFrame *YQRZ_40= new
    FXHorizontalFrame( YQRZ_157,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXButton *YQRZ_20;

  YQRZ_20= 
    new FXButton(YQRZ_40,
      "row2-1",
      VFLL1,
       NULL,
       0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_25;

  YQRZ_25= 
    new FXButton(YQRZ_40,
      "row2-2",
      NULL,
       NULL,
       0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXButton *YQRZ_30;

  YQRZ_30= 
    new FXButton(YQRZ_40,
      "row2-3",
      NULL,
       NULL,
       0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXToggleButton *YQRZ_35;

  YQRZ_35= 
    new FXToggleButton(YQRZ_40,
      "OFF", "ON", 
      NULL, NULL,
       NULL,
       0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXHorizontalFrame *YQRZ_52= new
    FXHorizontalFrame( YQRZ_157,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_41;

  YQRZ_41= 
    new FXLabel(YQRZ_52,
      "Source Directory",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXTextField *YQRZ_44;

  source_dir = YQRZ_44= 
    new FXTextField(YQRZ_52,
      40,
       NULL,
       0,
 
     LAYOUT_LEFT |
     LAYOUT_TOP |
     LAYOUT_SIDE_TOP |
     LAYOUT_FILL_X |
     0 |

    FRAME_SUNKEN|FRAME_THICK |
    JUSTIFY_LEFT |
    JUSTIFY_CENTER_Y
     
        ,

    0,0,0,0, // x,y,w,h

    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD,
    DEFAULT_PAD);




  FXButton *YQRZ_47;

  YQRZ_47= 
    new FXButton(YQRZ_52,
      "Browse..",
      NULL,
       NULL,
       0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXHorizontalFrame *YQRZ_59= new
    FXHorizontalFrame( YQRZ_157,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXLabel *YQRZ_53;

  YQRZ_53= 
    new FXLabel(YQRZ_59,
      "A spinner",
      NULL,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        0 |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  




  FXSpinner *YQRZ_56;

  YQRZ_56= 
    new FXSpinner(YQRZ_59, 3,
       // target and selector
       NULL, 0,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |
        0 |
       // there are some options, but I dont know how to use those yet.
        SPIN_NORMAL,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    
      YQRZ_56->setRange(3, 20);
    
    

  

  

  

  



  FXGroupBox *YQRZ_86;
  YQRZ_86= new FXGroupBox(YQRZ_157, "Selection", 
        GROUPBOX_TITLE_LEFT |  // FIXME: this shall be configurable
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        FRAME_LINE |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,
     0,0,0,0, // xywh
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


  FXHorizontalFrame *YQRZ_80= new
    FXHorizontalFrame( YQRZ_86,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);



  FXRadioButton * YQRZ_60;
  YQRZ_60= new FXRadioButton(YQRZ_80, "Foo 1", 
               this, YQRZ_61, 
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |
        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    append( radio1, YQRZ_60, 1 );

     YQRZ_60->setCheck(TRUE); radio1_store= 1; 
    


  

  

  

  




  FXRadioButton * YQRZ_65;
  YQRZ_65= new FXRadioButton(YQRZ_80, "Foo 2", 
               this, YQRZ_66, 
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |
        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    append( radio1, YQRZ_65, 4 );

    
     YQRZ_65->setCheck(FALSE); 


  

  

  

  




  FXRadioButton * YQRZ_70;
  YQRZ_70= new FXRadioButton(YQRZ_80, "Foo 3", 
               this, YQRZ_71, 
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |
        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    append( radio1, YQRZ_70, 9 );

    
     YQRZ_70->setCheck(FALSE); 


  

  

  

  




  FXRadioButton * YQRZ_75;
  YQRZ_75= new FXRadioButton(YQRZ_80, "Foo 4", 
               this, YQRZ_76, 
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |
        FRAME_NONE |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

    append( radio1, YQRZ_75, 16 );

    
     YQRZ_75->setCheck(FALSE); 


  

  

  

  




  FXButton *YQRZ_81;

  YQRZ_81= 
    new FXButton(YQRZ_86,
      "Print Selected..",
      NULL,
      this ,
      YQRZ_82 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXTabBook *YQRZ_129;
  YQRZ_129=  new FXTabBook(YQRZ_157,
           NULL, 0, // selector stuff

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |  0, // FIXME: do the tab-side stuff.

        0,0,0,0, // xywh
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING);

   
  FXTabItem *YQRZ_100;
  YQRZ_100= new FXTabItem( YQRZ_129,
                           "Int Keys", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_99= new
    FXVerticalFrame( YQRZ_129,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


   FXList *YQRZ_87; 

   YQRZ_87= numbers = new FXList(YQRZ_99,
        this
           ,
        YQRZ_88
           ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y 
                 ,0,0,0,0); // xywh


  

  

  

  




  FXButton *YQRZ_94;

  YQRZ_94= 
    new FXButton(YQRZ_99,
      "Test",
      NULL,
      this ,
      YQRZ_95 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXTabItem *YQRZ_114;
  YQRZ_114= new FXTabItem( YQRZ_129,
                           "No Keys", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_113= new
    FXVerticalFrame( YQRZ_129,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


   FXList *YQRZ_101; 

   YQRZ_101= strings = new FXList(YQRZ_113,
        this
           ,
        YQRZ_102
           ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y 
                 ,0,0,0,0); // xywh


  

  

  

  




  FXButton *YQRZ_108;

  YQRZ_108= 
    new FXButton(YQRZ_113,
      "Test",
      NULL,
      this ,
      YQRZ_109 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         


  FXTabItem *YQRZ_128;
  YQRZ_128= new FXTabItem( YQRZ_129,
                           "String Keys", NULL);
  // FIXME: do the fonts here

  FXVerticalFrame *YQRZ_127= new
    FXVerticalFrame( YQRZ_129,
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |
        0 |
        0 | 
        0 ,
        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_SPACING,
        DEFAULT_SPACING);


   FXList *YQRZ_115; 

   YQRZ_115= string_keys = new FXList(YQRZ_127,
        
           NULL,
        
           0,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y 
                 ,0,0,0,0); // xywh


  

  

  

  




  FXButton *YQRZ_122;

  YQRZ_122= 
    new FXButton(YQRZ_127,
      "Test",
      NULL,
      this ,
      YQRZ_123 ,

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        0 |
        0 |

        FRAME_RAISED|FRAME_THICK |
        ICON_BEFORE_TEXT |
        JUSTIFY_CENTER_X |
        JUSTIFY_CENTER_Y 

        

        
        
        ,

        0,0,0,0, // x,y,w,h
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD,
        DEFAULT_PAD);

  

  

  

  


   

         



  FXText *YQRZ_130;
  YQRZ_130= econ = new FXText(
       YQRZ_157, NULL,0, // target & selector
        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        0 |
        TEXT_WORDWRAP |
        VSCROLLER_ALWAYS |
        TEXT_READONLY | TEXT_AUTOSCROLL |
        0,
     0,0,0,0,  // x,y,w,h
             // FIXME: these are given as number constants in the
             // FXText constructor. Nothing symbolic like DEFAULT_PAD
             // etc. is used. So, I will do the same unwillingly.
     3,
     3,
     2,
     2);

  

  

  

  



  FXTabBook *YQRZ_150;
  YQRZ_150=  new FXTabBook(YQRZ_157,
           NULL, 0, // selector stuff

        LAYOUT_LEFT |
        LAYOUT_TOP |
        LAYOUT_SIDE_TOP |
        LAYOUT_FILL_X |
        LAYOUT_FILL_Y |  0, // FIXME: do the tab-side stuff.

        0,0,0,0, // xywh
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING,
        DEFAULT_SPACING);

   
  FXTabItem *YQRZ_138;
  YQRZ_138= new FXTabItem( YQRZ_150,
                           "Directories", NULL);
  // FIXME: do the fonts here


  FXDirList *YQRZ_133;
  YQRZ_133= dirs = new FXDirList(YQRZ_150,
            NULL,
            0,
             TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|
             DIRLIST_NO_OWN_ASSOC |
             0 |
             0 |

             LAYOUT_LEFT |
             LAYOUT_TOP |
             LAYOUT_SIDE_TOP |
             LAYOUT_FILL_X |
             LAYOUT_FILL_Y |
             FRAME_RAISED|FRAME_THICK 
           ,0,0,0,0);  // xywh

  

  

  

  



  FXTabItem *YQRZ_149;
  YQRZ_149= new FXTabItem( YQRZ_150,
                           "Files", NULL);
  // FIXME: do the fonts here


  FXFileList *YQRZ_139;
  YQRZ_139= files = new FXFileList(YQRZ_150,
           this ,
           YQRZ_140 ,
             FILELIST_NO_OWN_ASSOC |
             0 |
             0 |

             LAYOUT_LEFT |
             LAYOUT_TOP |
             LAYOUT_SIDE_TOP |
             LAYOUT_FILL_X |
             LAYOUT_FILL_Y |
             FRAME_RAISED|FRAME_THICK 
           ,0,0,0,0);  // xywh

  

  

  

  




   FXText  *YQRZ_151;
  YQRZ_151= textedit = 
         new FXText(YQRZ_157, this, YQRZ_152,
                  LAYOUT_FILL_X | LAYOUT_FILL_Y );
       



   FXButton  *YQRZ_154;
  YQRZ_154= selfbutton = 
        new FXButton(YQRZ_157, "What?", 0, this, YQRZ_155);
      






 }
 VFLL2:: ~ VFLL2() { }
 long VFLL2::handle_close
    (FXObject *object,FXSelector sel, void *arg)
 {
    /* window closing code would go here */
    return 0;
 } 
 


  long VFLL2::YQRZ_7
    (FXObject *object,FXSelector sel, void *arg)
       { printf("helloo!\n"); press_hello();  return 1; }





  long VFLL2::YQRZ_12
    (FXObject *object,FXSelector sel, void *arg)
       { printf("byyeee!\n"); press_bye();  return 1; }





  long VFLL2::YQRZ_17
    (FXObject *object,FXSelector sel, void *arg)
       {  printf("New button click!\n");
                             test_new_button();  return 1; }




























long VFLL2::YQRZ_64
  (FXObject *object,FXSelector sel, void *arg)
{
  set_value( radio1, 1 );
   printf("First one.\n"); 
  // FIXME: put the on_click stuff here
  return 1;
}



long VFLL2::YQRZ_69
  (FXObject *object,FXSelector sel, void *arg)
{
  set_value( radio1, 4 );
   printf("Second one.\n");
  // FIXME: put the on_click stuff here
  return 1;
}



long VFLL2::YQRZ_74
  (FXObject *object,FXSelector sel, void *arg)
{
  set_value( radio1, 9 );
   printf("Third one.\n");
  // FIXME: put the on_click stuff here
  return 1;
}



long VFLL2::YQRZ_79
  (FXObject *object,FXSelector sel, void *arg)
{
  set_value( radio1, 16 );
   printf("Fourth one.\n");
  // FIXME: put the on_click stuff here
  return 1;
}




  long VFLL2::YQRZ_85
    (FXObject *object,FXSelector sel, void *arg)
       {  printf("Selected: %d\n", radio1_store);  return 1; }




 long VFLL2::YQRZ_91
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_93= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_93->getItem(clicked_item));

      int clicked_key = item->data_i;
      
      
      
      
                printf("clicked item %d: key= %d\n", clicked_item,
                                                     clicked_key);
             
      return 1;
    }







  long VFLL2::YQRZ_98
    (FXObject *object,FXSelector sel, void *arg)
       {  test_int_list();  return 1; }





 long VFLL2::YQRZ_106
    (FXObject *object,FXSelector sel, void *arg)
    {
      FXList *YQRZ_107= (FXList*)(object);
      int clicked_item= (intptr_t) (arg);
      FYListItem *item= (FYListItem*) (YQRZ_107->getItem(clicked_item));

      
      
      
      
      
                printf("Double click!\n");
             
      return 1;
    }






  long VFLL2::YQRZ_112
    (FXObject *object,FXSelector sel, void *arg)
       {  test_dispstr_list();  return 1; }










  long VFLL2::YQRZ_126
    (FXObject *object,FXSelector sel, void *arg)
       {  test_str_list();  return 1; }




  



  
long VFLL2::YQRZ_143
     (FXObject *object, FXSelector sel, void *arg)
{
   FXFileList *YQRZ_145= (FXFileList*) object;
   int YQRZ_146= (intptr_t) arg;
   FXString YQRZ_147= YQRZ_145->getItemPathname(YQRZ_146);
   const char *clicked_path=YQRZ_147.text(); 
   FXString YQRZ_148= YQRZ_145->getItemFilename(YQRZ_146);
   const char *clicked_name= YQRZ_148.text();
   if (YQRZ_145->isItemFile(YQRZ_146))
   {
       printf("File: %s : %s\n",  clicked_path,
                                                      clicked_name); 
      return 1;
   }
   if (YQRZ_145->isItemDirectory(YQRZ_146))
   {
       files->setDirectory(clicked_path); 
      return 1;
   }
   return 1;
}
  


  



long VFLL2::YQRZ_153
    (FXObject *object,FXSelector sel, void *arg)
       { 
          printf("Inserted!\n");
        return 1; }


long VFLL2::YQRZ_156
    (FXObject *object,FXSelector sel, void *arg)
       { 
        printf("El clicko!\n");
       return 1; }




  

 gui_testmain_t *gui_c_testmain()
 {
    // ffo -> fox form object
    // ifo -> interface form object 
   VFLL2 *ffo;
   gui_testmain_t * ifo;
   ffo= new VFLL2(
       FXApp::instance(),
       "good window",
       NULL, NULL, // FIXME: icons
       DECOR_ALL ,
       0, 0,
       400, 400,
       0, 0,
       0, 0,
       0, 0);
   // If the application has not been created, this will done
   // when the application gets created. Otherwise, we have
   // to explicitly do this.
   if (app_created) 
     ffo->create();
   
   ffo->show(PLACEMENT_SCREEN);

   ifo= (typeof(ifo)) malloc(sizeof(*ifo));
   ifo->self= ffo;
    
 ifo->radio1.widget= ffo->radio1;
 ifo->radio1.cls= &gui_radio_group_class;




 ifo->cool_button.widget= ffo->cool_button;
 ifo->cool_button.cls= &gui_button_class;





 ifo->foo_button.widget= ffo->foo_button;
 ifo->foo_button.cls= &gui_button_class;




 
  ifo->allnew.widget= ffo->allnew;
  ifo->allnew.cls= & gui_newbutton_class;
 



 



 



 


 
 ifo->source_dir.widget= ffo->source_dir;
 ifo->source_dir.cls= &gui_text_entry_class;



 



 

 


 




  
    ifo->numbers.cls= & gui_intlist_class;
    ifo->numbers.widget= ffo->numbers;
   

 




  
    ifo->strings.cls= & gui_sslist_class;
    ifo->strings.widget= ffo->strings;
   

 




  
    ifo->string_keys.cls= & gui_slist_class;
    ifo->string_keys.widget= ffo->string_keys;
   

 






  ifo->econ.widget= ffo->econ;
  ifo->econ.cls= &gui_message_console_class;




  
    ifo->dirs.widget= ffo->dirs;
    ifo->dirs.cls= &gui_dir_list_class;
  


  
    ifo->files.widget= ffo->files;
    ifo->files.cls= &gui_file_list_class;
  


  
     ifo->textedit= ffo->textedit;
  


  
     ifo->selfbutton= ffo->selfbutton;
  


   return ifo;
 }




static FXApp *app;

void gui_init(int *argc,char **argv)
{
  app= new FXApp("YAK", "KUT");
  app->init(*argc, argv);
  app->create();
    // YQRZ_11->create(); 
    
  VFLL1= new FXPNGIcon(app, YQRZ_19);
  VFLL1->create();

  app_created= 1;
}

void gui_run()
{
  app->run();
}

void gui_flush()
{
  app->runWhileEvents();
}



